@@ -1,4 +1,3 @@
-from numpy import ndarray
 from typing import Dict, List, Union
 
 from EasyMCDM.models.MCDM import MCDM
@@ -14,7 +13,7 @@ class Electre(MCDM):
     ]
 
     # Constructor
-    def __init__(self, data : Union[str, ndarray, dict], col_sep=',', row_sep='\n', verbose=True):
+    def __init__(self, data : Union[str, dict], col_sep=',', row_sep='\n', verbose=True):
         super().__init__(data, col_sep=col_sep, row_sep=row_sep, verbose=verbose)
 
     def __print_electre__(
